<div class='jsign-wrapper'>
  {{ hidden }}
  <div id='{{ jsign_id }}'
       data-config='{{ js_config }}'
       data-initial-value='{{ value }}'
       class='jsign-container'></div>
  {% if config.ResetButton %}
    <input type='button' value='{{ reset_btn_text }}' class="btn">
  {% endif %}
</div>